InspectorManager
=================================

.. autoclass:: sdgx.data_models.inspectors.manager.InspectorManager
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
   :private-members:
